@@ -1055,7 +1055,7 @@ class KamibotPi:
             dir (int): 방향 'l': 왼쪽으로, 'r': 오른쪽으로
             value (int): 각도값
             speed (int): 회전 속도
-            torque (int): 모터 힘 (1~9)
+            torque (int): 모터 힘 (1~5)
 
         Returns:
             None
@@ -1078,7 +1078,7 @@ class KamibotPi:
         command[PacketIndex.DATA1] = (value >> 8) & 0x00ff
         command[PacketIndex.DATA2] = dir
         command[PacketIndex.DATA3] = speed
-        command[PacketIndex.DATA3] = torque
+        command[PacketIndex.DATA4] = torque
         command[PacketIndex.INDEX] = self.__get_idx()
         try:
             self.sr.write(bytes(bytearray(command)))
@@ -1088,13 +1088,14 @@ class KamibotPi:
         self.__process_return()
         return None
 
-    def top_motor_abspos(self,  degree=0, speed=50):
+    def top_motor_abspos(self,  degree=0, speed=50,torque=1):
         """탑모터 절대 각도 위치로 이동시키기
 
         Args:
             dir (int): 방향 'l': 왼쪽으로, 'r': 오른쪽으로
             degree (int): 각도값
             speed (int): 회전 속도
+            torque (int): 모터 힘 (1~5)
 
         Returns:
             None
@@ -1112,6 +1113,7 @@ class KamibotPi:
         command[PacketIndex.DATA1] = (degree >> 8) & 0x00ff
         command[PacketIndex.DATA2] = 0x03  # 절대각도
         command[PacketIndex.DATA3] = speed
+        command[PacketIndex.DATA4] = torque
         command[PacketIndex.INDEX] = self.__get_idx()
         try:
             self.sr.write(bytes(bytearray(command)))
@@ -1149,13 +1151,14 @@ class KamibotPi:
         self.__process_return()
         return None
 
-    def top_motor_time(self, dir, value=3, speed=50):
+    def top_motor_time(self, dir, value=3, speed=50,torque=1):
         """탑모터 방향을 지정해서 정해진 시간마큼 회전시키기
 
         Args:
             dir (int): 방향 'l': 왼쪽으로, 'r': 오른쪽으로
             value (int): 회전 시간을 초단위로 지정
             speed (int): 회전 속도
+            torque (int): 모터 힘 (1~5)
         Returns:
             None
         """
@@ -1179,6 +1182,7 @@ class KamibotPi:
         command[PacketIndex.DATA1] = (value >> 8) & 0x00ff
         command[PacketIndex.DATA2] = dir
         command[PacketIndex.DATA3] = speed
+        command[PacketIndex.DATA4] = torque
         command[PacketIndex.INDEX] = self.__get_idx()
         try:
             self.sr.write(bytes(bytearray(command)))
@@ -1188,13 +1192,15 @@ class KamibotPi:
         self.__process_return()
         return None
 
-    def top_motor_round(self,  dir, value=1, speed=50):
+    def top_motor_round(self,  dir, value=1, speed=50,torque=1,infinite=0):
         """탑모터 방향을 지정해서 정해진만큼 회전시키기
 
         Args:
             dir (int): 방향 'left': 왼쪽으로, 'right': 오른쪽으로
             value (int): 회전수
             speed (int): 회전 속도
+            torque (int): 모터 힘 (1~5)
+            infinite (int) : 무한 회전 ,  '0':지정 횟수만큼 회전, '1': 무한회전
         Returns:
             None
         """
@@ -1210,6 +1216,10 @@ class KamibotPi:
             value = 0x00
             speed = 0x00
 
+        if infinite == 1:
+            value = 0xffff
+
+
         command = NULL_COMMAND_PACKET[:]
         command[PacketIndex.COMMANDTYPE] = COMMANDTYPE_WRITE
         command[PacketIndex.MODETYPE] = ModeType.TOP_STEPPER
@@ -1218,6 +1228,7 @@ class KamibotPi:
         command[PacketIndex.DATA1] = (value >> 8) & 0x00ff
         command[PacketIndex.DATA2] = dir
         command[PacketIndex.DATA3] = speed
+        command[PacketIndex.DATA4] = torque
         command[PacketIndex.INDEX] = self.__get_idx()
         try:
             self.sr.write(bytes(bytearray(command)))
